
This is a **richtext widget** for for `YAFOWIL 
<http://pypi.python.org/pypi/yafowil>`_ 

It uses for now TinyMCE as wysiwig-editor.

Source Code
===========

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/bluedynamics/yafowil.widget.dynatree>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.


Contributors
============

- Robert Niederrreiter <rnix@squarewave.at>
